#ifdef GL_ES
precision lowp float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
uniform float uTime;

// Params = (wave frequency in Hz, number of waves per unit distance)
//
vec2 params = vec2(2.5, 10.0);

// Simple circular wave function
float wave(vec2 pos, float t, float freq, float numWaves, vec2 center) {
	float d = length(pos - center);
	d = log(1.0 + exp(d));
	return 1.0/(1.0+20.0*d*d) *
    sin(2.0*3.1415*(-numWaves*d + t*freq));
}

// This height map combines a couple of waves
float height(vec2 pos, float t) {
	float w;
	w =  wave(pos, t, params.x, params.y, vec2(0.5, -0.5));
	w += wave(pos, t, params.x, params.y, -vec2(0.5, -0.5));
	return w;
}

// Discrete differentiation
vec2 normal(vec2 pos, float t) {
	return 	vec2(height(pos - vec2(0.01, 0), t) - height(pos, t),
				 height(pos - vec2(0, 0.01), t) - height(pos, t));
}


void main()
{
    
    //gl_FragColor = v_fragmentColor * texture2D(CC_Texture0, v_texCoord);
    
	if(gl_FragColor.b <= 0.95)
	{
        if(gl_FragColor.b <= 0.80)
        {
            gl_FragColor *= 0.0;
        }
        else
        {
            gl_FragColor = vec4(1.0,1.0,1.0,0.1);
        }
	}
    else
    {
        
        
        vec2 iResolution = vec2(960.0, 640.0);
        params = vec2(4.5, 10.0);
        vec2 uv = gl_FragCoord.xy / iResolution.xy;
        vec2 uvn = 2.0*uv - vec2(1.0);
        uv += normal(uvn, uTime);
        vec4 color = texture2D(CC_Texture1, vec2(uv.x, uv.y));
        
        //
        gl_FragColor.rgb = vec3(0.0, 16.0/100.0, 31.0/100.0);
        color.rgb = gl_FragColor.rgb + color.rgb;
        gl_FragColor = color;
    }
    
}